==> haskell-onetuple-0.4.1.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-onetuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 OneTuple
version:              0.4.1.1
visibility:           public
id:                   OneTuple-0.4.1.1-4lwIRfu11dw45Vo4MVeyjM
key:                  OneTuple-0.4.1.1-4lwIRfu11dw45Vo4MVeyjM
license:              BSD-3-Clause
copyright:            (c) John Dorsey 2008
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, John Dorsey <haskell@colquitt.org>

author:               John Dorsey <haskell@colquitt.org>
stability:            experimental
synopsis:             Singleton Tuple
description:
    This package is a compatibility package for a singleton data type

    > data Solo a = MkSolo a

    Note: it'\''s not a @newtype@

    @Solo@ is available in @base-4.16@ (GHC-9.2).

category:             Data
abi:                  3ab5734d90f18a4d7471a2c8ab428b31
exposed:              True
exposed-modules:
    Data.Tuple.OneTuple Data.Tuple.Solo Data.Tuple.Solo.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/OneTuple-0.4.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/OneTuple-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-onetuple
hs-libraries:         HSOneTuple-0.4.1.1-4lwIRfu11dw45Vo4MVeyjM
depends:
    base-4.16.4.0 ghc-prim-0.8.0 template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-onetuple/html/OneTuple.haddock
haddock-html:         /usr/share/doc/haskell-onetuple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-onetuple-0.4.1.1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-onetuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 OneTuple
version:              0.4.1.1
visibility:           public
id:                   OneTuple-0.4.1.1-D5ZQmCINWVmH8ekcJQv0ip
key:                  OneTuple-0.4.1.1-D5ZQmCINWVmH8ekcJQv0ip
license:              BSD-3-Clause
copyright:            (c) John Dorsey 2008
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, John Dorsey <haskell@colquitt.org>

author:               John Dorsey <haskell@colquitt.org>
stability:            experimental
synopsis:             Singleton Tuple
description:
    This package is a compatibility package for a singleton data type

    > data Solo a = MkSolo a

    Note: it'\''s not a @newtype@

    @Solo@ is available in @base-4.16@ (GHC-9.2).

category:             Data
abi:                  8ff9c1a16c5519eb0a3224e2f9574d6d
exposed:              True
exposed-modules:
    Data.Tuple.OneTuple Data.Tuple.Solo Data.Tuple.Solo.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/OneTuple-0.4.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/OneTuple-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-onetuple
hs-libraries:         HSOneTuple-0.4.1.1-D5ZQmCINWVmH8ekcJQv0ip
depends:
    base-4.16.4.0 ghc-prim-0.8.0 template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-onetuple/html/OneTuple.haddock
haddock-html:         /usr/share/doc/haskell-onetuple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
